/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.core;

import junit.framework.TestCase;


/**
 * Tests for {@link OptParameters} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestOptParameters extends TestCase {

    /**
     * Empty default constructor
     */
    public TestOptParameters() { }

    /**
     * Creates new instance of anonymous subclass if {@link OptParameters} that represents
     * string parameters.
     *
     * @return new object representing string parameters
     */
    private OptParameters makeStringParameters() {
        OptParameters params = new OptParameters() {
            public Type getType() {
                return Type.STRING;
            }
        };
        return params;
    }

    /**
     * Tests {@link OptParameters#configure(int)} method.
     */
    public void testConfigure() {
        OptParameters params = makeStringParameters();
        params.configure(2);
    }

    /**
     * Tests {@link OptParameters#configure(int)} method trying to call it twice.
     */
    public void testConfigureRepeatet() {
        OptParameters params = makeStringParameters();
        params.configure(2);
        try {
            params.configure(2);
            fail();
        } catch (IllegalStateException e) {
            // OK
        }
    }

    /**
     * Tests {@link OptParameters#configure(int)} method with invalid <code>paramIndex</code>
     * argument.
     */
    public void testConfigureInvalidArg() {
        OptParameters params;
        try {
            params = makeStringParameters();
            params.configure(-1);
            fail();
        } catch (IllegalArgumentException e) {
            // OK
        }
        try {
            params = makeStringParameters();
            params.configure(Integer.MIN_VALUE);
            fail();
        } catch (IllegalArgumentException e) {
            // OK
        }
    }

    /**
     * Tests {@link OptParameters#getStartIndex()} method.
     */
    public void testGetIndex() {
        OptParameters params = makeStringParameters();
        params.configure(2);
        assertEquals(params.getStartIndex(), 2);
        params = makeStringParameters();
        params.configure(Integer.MAX_VALUE);
        assertEquals(params.getStartIndex(), Integer.MAX_VALUE);
    }

    /**
     * Tests {@link OptParameters#getStartIndex()} method by calling it on unconfigured object.
     */
    public void testGetIndexUnconfigured() {
        OptParameters params = makeStringParameters();
        try {
            params.getStartIndex();
            fail();
        } catch (IllegalStateException e) {
            // OK
        }
    }

    /**
     * Tests {@link OptParameters#getType()} method.
     */
    public void testGetType() {
        OptParameters params = makeStringParameters();
        assertSame(params.getType(), Type.STRING);
        params.configure(2);
        assertSame(params.getType(), Type.STRING);
    }

}
