/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.evaluator;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.TestValue;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.optparameters.IntegerOptParameters;


/**
 * Test integer function that sums all integer parameters.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public class FnIntSum extends IntegerFunction {

    /**
     * Integer parameters to add together
     */
    private static final IntegerOptParameters pOptValues = new IntegerOptParameters();

    /**
     * The function's signature
     */
    private static final FunctionSignature signature =
        new FunctionSignature(new Parameter[0], pOptValues);

    /**
     * {@inheritDoc}
     */
    public FunctionSignature getSignature() {
        return signature;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return "intsum";
    }

    /**
     * {@inheritDoc}
     */
    protected long execute() {
        long result = 0;
        int optParamsCount = getOptParametersCount(pOptValues);
        for (int i = 0; i < optParamsCount; i++) {
            result += getParameter(pOptValues, i);
        }
        return result;
    }

    /**
     * Returns the result of function evaluation, operating directly on {@link Value} instances.
     *
     * @param parameters parameters used for evaluation
     * @return evaluation result
     */
    public static Value testExecute(Value[] parameters) {
        long result = 0;
        for (int i = 0; i < parameters.length; i++) {
            result += parameters[i].getInteger();
        }
        return TestValue.makeInteger(result);
    }

}
