/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.evaluator;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.TestValue;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.optparameters.StringOptParameters;
import pl.chyla.wyjec.utils.RawString;


/**
 * Test string function that concatenates all parameters into single string.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public class FnStrConcat extends StringFunction {

    /**
     * String parameters to concatenate
     */
    private static final StringOptParameters pOptValues = new StringOptParameters();

    /**
     * The function's signature
     */
    private static final FunctionSignature signature =
        new FunctionSignature(new Parameter[0], pOptValues);

    /**
     * {@inheritDoc}
     */
    public FunctionSignature getSignature() {
        return signature;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return "strconcat";
    }

    /**
     * {@inheritDoc}
     */
    protected void execute(RawString result) {
        int optParamsCount = getOptParametersCount(pOptValues);
        for (int i = 0; i < optParamsCount; i++) {
            result.append(getParameter(pOptValues, i));
        }
    }

    /**
     * Returns the result of function evaluation, operating directly on {@link Value} instances.
     *
     * @param parameters parameters used for evaluation
     * @return evaluation result
     */
    public static Value testExecute(Value[] parameters) {
        StringBuffer resultBuffer = new StringBuffer();
        for (int i = 0; i < parameters.length; i++) {
            resultBuffer.append(parameters[i].getString().toString());
        }
        return TestValue.makeString(resultBuffer.toString());
    }

}
