/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.lexer;

import java.util.Arrays;
import junit.framework.TestCase;


/**
 * Tests for {@link Token} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestToken extends TestCase {

    /**
     * Empty default constructor
     */
    public TestToken() { }

    /**
     * Tests whether string representations of tokens are valid.
     */
    public void testTokenNames() {
        assertEquals(Token.getName(Token.STRING), "STRING");
        assertEquals(Token.getName(Token.SEPARATOR), "SEPARATOR");
        assertEquals(Token.getName(Token.FUNCTION_START), "FUNCTION_START");
        assertEquals(Token.getName(Token.FUNCTION_END), "FUNCTION_END");
        assertEquals(Token.getName(Token.TERMINATOR), "TERMINATOR");
    }

    public void testInvalidToken() {
        int[] tokens = {
            Token.STRING, Token.SEPARATOR, Token.FUNCTION_START, Token.FUNCTION_END,
            Token.TERMINATOR};
        Arrays.sort(tokens);
        if (tokens[0] > Integer.MIN_VALUE) {
            checkInvalidToken(tokens[0] - 1);
        }
        if (tokens[tokens.length - 1] < Integer.MAX_VALUE) {
            checkInvalidToken(tokens[tokens.length - 1] + 1);
        }
        for (int i = 1; i < tokens.length; i++) {
            if (tokens[i] - tokens[i - 1] > 1) {
                checkInvalidToken(tokens[i] - 1);
            }
        }
    }

    /**
     * Checks if {@link Token#getName} throws <code>IllegalPathStateException</code> for given
     * invalid token type.
     *
     * @param tokenType value representing invalid token type
     */
    private void checkInvalidToken(int tokenType) {
        try {
            Token.getName(tokenType);
            fail();
        } catch (IllegalArgumentException e) {
            // OK
        }
    }

}
