/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.parser;


/**
 * Abstract base class for objects containing descriptions of atom nodes (values or references
 * to functions) in expression tree. For each such description it's possible to generate the
 * corresponding part of expression tree.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public abstract class AtomNodeDescription {

    /**
     * Generates atom node specified by this description object, together with all linked nodes,
     * e.g. nodes representing function parameters. All instances representing nodes of
     * expression tree will be acquired from given pool.
     *
     * @param pool a pool used to generate instances of expression tree nodes
     * @return part of expression tree starting with atom node described by this object
     */
    public abstract AtomNode makeAtomNode(ExprTreePool pool);

    /**
     * Informs whether this description matches given real atom node.
     *
     * @param atomNode atom node to check this description against
     * @return
     *     <code>true</code> if this description matches given node, <code>false</code>
     *     otherwise
     */
    public abstract boolean isMatching(AtomNode atomNode);

}
