/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.parser;

import pl.chyla.wyjec.core.Value;


/**
 * Class describing expression tree node representing constant value.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class ValueNodeDescription extends AtomNodeDescription {

    /**
     * Value of the node described by this object.
     */
    private final Value value;

    /**
     * Constructs <code>ValueNodeDescription</code> instance, using given value as a content of
     * described node.
     *
     * @param value value of the node, it shouldn't be modified after calling the constructor
     */
    public ValueNodeDescription(Value value) {
        this.value = value;
    }

    /**
     * Generates value node specified by this description object.
     *
     * @param pool a pool used to generate value node
     * @return atom node described by this object
     */
    public AtomNode makeAtomNode(ExprTreePool pool) {
        ValueNode valueNode = pool.getValueNode();
        Value v = pool.getValue();
        v.set(value);
        valueNode.set(v);
        return valueNode;
    }

    /**
     * Informs whether this description matches given real atom node. The node matches if it's
     * a value node and its contained value is equal to the one contained in the description.
     *
     * @param atomNode atom node to check this description against.
     * @return
     *     <code>true</code> if this description matches given node, <code>false</code>
     *     otherwise
     */
    public boolean isMatching(AtomNode atomNode) {
        boolean result;
        if (atomNode.getAtomType() == AtomType.VALUE) {
            ValueNode valueNode = atomNode.getAsValueNode();
            result = valueNode.getValue().equals(value);
        } else {
            result = false;
        }
        return result;
    }

}
