/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.repo;

import pl.chyla.wyjec.core.Type;


/**
 * Describes types used in declaration consisting of a sequence of required types and single
 * optional type.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
class TypesDeclaration {

    /**
     * Required types
     */
    final Type[] requiredTypes;

    /**
     * Optional type
     */
    final Type optionalType;

    /**
     * Constructs <code>TypesDeclaration</code> with specified types.
     *
     * @param requiredTypes required types
     * @param optionalType optional type
     */
    TypesDeclaration(Type[] requiredTypes, Type optionalType) {
        this.requiredTypes = requiredTypes;
        this.optionalType = optionalType;
    }

    /**
     * Returns part of declaration containing required types.
     *
     * @return array of required types
     */
    Type[] getRequiredTypes() {
        return requiredTypes;
    }

    /**
     * Returns part of declaration containing optional type.
     *
     * @return optional type or {@link Type#NONE} if there's no optional type 
     */
    Type getOptionalType() {
        return optionalType;
    }

}
