/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdconsts;

import pl.chyla.wyjec.core.TestValue;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.utils.RawString;
import pl.chyla.wyjec.utils.TestRawString;
import junit.framework.TestCase;


/**
 * Tests for {@link pl.chyla.wyjec.stdconsts.IntegerConstantsParser} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestIntegerConstantsParser extends TestCase {

    /**
     * Strings to be used in float constants as sign before integer digits or exponent digits.
     */
    private static final String[] signStrings = {"", "+", "-"};

    /**
     * Instance of constants parser to use by tests.
     */
    private IntegerConstantsParser constsParser;

    /**
     * Empty default constructor
     */
    public TestIntegerConstantsParser() { }

    /**
     * {@inheritDoc}
     */
    protected void setUp() throws Exception {
        super.setUp();
        constsParser = IntegerConstantsParser.getInstance();
    }

    /**
     * Tests {@link IntegerConstantsParser#parseConstant(Value, ReadableRawString)} method,
     * passing invalid strings to parse.
     */
    public void testParseConstantInvalid() {
        String[] constStrings = {
            "", " ", "   ", " 0", "0 ", "d123", "123d", "1000000000000000000",
            "9876543210987654321", "00000000001000000000000000000"};
        RawString[] constRStrings = TestRawString.buildRawStringsVariants(constStrings);
        Value value = new Value(0);
        for (int i = 0; i < constRStrings.length; i++) {
            assertFalse(constsParser.parseConstant(value, constRStrings[i]));
        }
    }

    /**
     * Tests {@link IntegerConstantsParser#parseConstant(Value, ReadableRawString)} method,
     * comparing its results with values generated by {@link Long#parseLong(java.lang.String)}.
     */
    public void testParseConstantValid() {
        String[] digitsStrings = {
            "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "987654321",
            "0000000000000000000012345678", "00000000000000000000999999999999999999",
            "999999999999999999", "987654321098765432"};
        Value value = new Value(0);
        for (int si = 0; si < signStrings.length; si++) {
            for (int i = 0; i < digitsStrings.length; i++) {
                String constStr = signStrings[si] + digitsStrings[i];
                long expectedValue;
                if (constStr.startsWith("+")) {
                    expectedValue = Long.parseLong(constStr.substring(1));
                } else {
                    expectedValue = Long.parseLong(constStr);
                }
                RawString[] constRStrings =
                    TestRawString.buildRawStringVariants(constStr);
                for (int rsi = 0; rsi < constRStrings.length; rsi++) {
                    assertTrue(constsParser.parseConstant(value, constRStrings[rsi]));
                    assertEquals(value, TestValue.makeInteger(expectedValue));
                }
            }
        }
    }

}
