/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdconsts;

import junit.framework.TestCase;
import pl.chyla.wyjec.core.TestValue;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.utils.RawString;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Tests for {@link pl.chyla.wyjec.stdconsts.StandardConstantsParser} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestStandardConstantsParser extends TestCase {

    /**
     * Empty default constructor
     */
    public TestStandardConstantsParser() { }

    /**
     * Tests {@link StandardConstantsParser#parseConstant(Value, ReadableRawString)} method.
     */
    public void testParseConstant() {
        StandardConstantsParser parser = StandardConstantsParser.getInstance();
        Value value = new Value(0);
        assertFalse(parser.parseConstant(value, new RawString("")));
        assertFalse(parser.parseConstant(value, new RawString(" ")));
        assertTrue(parser.parseConstant(value, new RawString("12345")));
        assertEquals(value, TestValue.makeInteger(12345L));
        assertTrue(parser.parseConstant(value, new RawString("1234.5")));
        assertEquals(value, TestValue.makeFloat(1234.5));
        assertTrue(parser.parseConstant(value, new RawString("@1977-03-09")));
        assertEquals(value, TestValue.makeDate(1977, 3, 9, 0, 0, 0));
    }

}
