/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.accessors;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestIntegerFunction;


/**
 * Tests for {@link FnMonth} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnMonth extends BaseTestIntegerFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnMonth() {
        super(new FnMonth());
    }

    /**
     * Evaluates {@link FnMonth} function with given <code>date</code> parameter and checks if
     * the result is equal to the expected result.
     *
     * @param dateParam value of <code>date</code> parameter to pass to the function
     * @param expResult expected result of function evaluation
     */
    private void checkFnMonth(Value dateParam, long expResult) {
        checkFunctionResult(new Value[] {dateParam}, expResult);
    }

    /**
     * Tests implementation of the function for a few selected dates.
     */
    public void testEvaluate() {
        checkFnMonth(
            makeDateValue(1970, 1, 1, 0, 0, 0),
            1);
        checkFnMonth(
            makeDateValue(1977, 3, 9, 21, 0, 0),
            3);
        checkFnMonth(
            makeDateValue(1977, 2, 28, 23, 30, 0),
            2);
        checkFnMonth(
            makeDateValue(1977, 3, 1, 0, 30, 0),
            3);
        checkFnMonth(
            makeDateValue(1977, 12, 31, 23, 59, 59),
            12);
        checkFnMonth(
            makeDateValue(1978, 1, 1, 0, 0, 0),
            1);
        checkFnMonth(
            makeDateValue(2000, 2, 28, 23, 30, 0),
            2);
        checkFnMonth(
            makeDateValue(2000, 3, 1, 0, 30, 0),
            3);
    }

}
