/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.basic;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnFormat} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnFormat extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnFormat() {
        super(new FnFormat());
    }

    /**
     * Evaluates {@link FnFormat} function with given parameters using different variants of
     * <code>format</code> parameter {@link pl.chyla.wyjec.utils.RawString} equivalent and
     * checks if the result is always equal to the expected result.
     *
     * @param formatParam value of <code>format</code> parameter to pass to the function
     * @param dateParam value of <code>date</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnFormat(String formatParam, Value dateParam, String expResult) {
        Value[] formatParamVariants = makeStringValueVariants(formatParam);
        for (int i = 0; i < formatParamVariants.length; i++) {
        checkFunctionResultVarSizes(
            new Value[] {formatParamVariants[i], dateParam},
            expResult);
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        Value dateParam = makeDateValue(1977, 3, 9, 14, 25, 36);
        checkFnFormat("", dateParam, "");
        checkFnFormat("%", dateParam, "%");
        checkFnFormat(
            "%--%-- %D_%T ++%++%",
            dateParam,
            "%--%-- 1977-03-09_14:25:36 ++%++%");
        checkFnFormat(
            "- %S%M%H%I +",
            dateParam,
            "- 36251402 +");
        checkFnFormat(
            "- %d%m%y%Y +",
            dateParam,
            "- 0903771977 +");
        checkFnFormat(
            "- %%Y +",
            dateParam,
            "- %Y +");
    }

}
