/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.basic;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnStr} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnStr extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnStr() {
        super(new FnStr());
    }

    /**
     * Evaluates {@link FnStr} function with given <code>date</code> parameter and checks if
     * the result is equal to the expected result.
     *
     * @param dateParam value of <code>date</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnStr(Value dateParam, String expResult) {
        checkFunctionResultVarSizes(new Value[] {dateParam}, expResult);
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnStr(
            makeDateValue(1970, 1, 1, 0, 0, 0),
            "1970-01-01 00:00:00");
        checkFnStr(
            makeDateValue(1977, 3, 9, 12, 34, 56),
            "1977-03-09 12:34:56");
        checkFnStr(
            makeDateValue(1977, 12, 31, 23, 59, 59),
            "1977-12-31 23:59:59");
        checkFnStr(
            makeDateValue(1978, 1, 1, 0, 1, 2),
            "1978-01-01 00:01:02");
    }

}
