/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.selection;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestDateFunction;


/**
 * Tests for {@link FnSelect} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnSelect extends BaseTestDateFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnSelect() {
        super(new FnSelect());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        Value aValue = makeDateValue(1977, 3, 9, 21, 0, 0);
        Value bValue = makeDateValue(1978, 9, 11, 151, 0, 0);
        Value cValue = makeDateValue(1975, 4, 9, 18, 0, 0);
        Value dValue = makeDateValue(1949, 3, 31, 17, 21, 32);
        checkFunctionResult(
            new Value[] {aValue, makeIntegerValue(0)},
            aValue.getDate());
        checkFunctionResult(
            new Value[] {aValue, makeIntegerValue(-2)},
            aValue.getDate());
        checkFunctionResult(
            new Value[] {aValue, makeIntegerValue(3)},
            aValue.getDate());
        checkFunctionResult(
            new Value[] {aValue, makeIntegerValue(-2), bValue, cValue},
                aValue.getDate());
        checkFunctionResult(
            new Value[] {aValue, makeIntegerValue(2), bValue, cValue},
                aValue.getDate());
        checkFunctionResult(
            new Value[] {aValue, makeIntegerValue(2), bValue, cValue, dValue},
            dValue.getDate());
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        params[0] = aValue;
        params[1] = makeIntegerValue(DEFAULT_PARAMS_SOFT_LIMIT - 2 - 1);
        Arrays.fill(params, 2, params.length, bValue);
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = cValue;
        checkFunctionResult(params, cValue.getDate());
    }

}
