/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestFloatFunction;


/**
 * Tests for {@link FnFloor} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnFloor extends BaseTestFloatFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnFloor() {
        super(new FnFloor());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFunctionResult(
            new Value[] {makeFloatValue(0.0)},
            0.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(0.5)},
            0.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(0.0025)},
            0.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(-0.5)},
            -1.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(-0.0025)},
            -1.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(1234567890123456.789)},
            1234567890123456.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(-1234567890123456.789)},
            -1234567890123457.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(12345.67e123)},
            12345.67e123);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.POSITIVE_INFINITY)},
            Double.POSITIVE_INFINITY);
        checkFunctionResult(
            new Value[] {makeFloatValue(-12345.67e123)},
            -12345.67e123);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.NEGATIVE_INFINITY)},
            Double.NEGATIVE_INFINITY);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.NaN)},
            Double.NaN);
    }

}
