/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestFloatFunction;


/**
 * Tests for {@link FnMultiplication} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnMultiplication extends BaseTestFloatFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnMultiplication() {
        super(new FnMultiplication());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        double aValue = 123456.789;
        double bValue = -1.456;
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue)},
            aValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeFloatValue(1.0)},
            aValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeFloatValue(0.0)},
            0.0);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeFloatValue(bValue)},
            aValue * bValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(bValue), makeFloatValue(Double.POSITIVE_INFINITY)},
            Double.NEGATIVE_INFINITY);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(Double.POSITIVE_INFINITY),
                makeFloatValue(Double.NEGATIVE_INFINITY)},
            Double.NEGATIVE_INFINITY);
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, makeFloatValue(1.0));
        checkFunctionResult(params, 1.0);
        params[0] = makeFloatValue(aValue);
        checkFunctionResult(params, aValue);
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = makeFloatValue(bValue);
        checkFunctionResult(params, aValue * bValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(aValue), makeFloatValue(1.0),
                makeFloatValue(bValue), makeFloatValue(aValue)},
            aValue * bValue * aValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.NaN)},
            Double.NaN);
        checkFunctionResult(
            new Value[] {makeFloatValue(2.0), makeFloatValue(Double.NaN)},
            Double.NaN);
    }

}
