/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.selection;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestFloatFunction;


/**
 * Tests for {@link FnIf} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnIf extends BaseTestFloatFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnIf() {
        super(new FnIf());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        double aValue = 3.5;
        double bValue = -7.5;
        checkFunctionResult(
            new Value[] {
                makeBooleanValue(true), makeFloatValue(aValue), makeFloatValue(bValue)},
            aValue);
        checkFunctionResult(
            new Value[] {
                makeBooleanValue(false), makeFloatValue(aValue), makeFloatValue(bValue)},
            bValue);
        checkFunctionResult(
            new Value[] {
                makeBooleanValue(true), makeFloatValue(Double.NEGATIVE_INFINITY),
                makeFloatValue(Double.POSITIVE_INFINITY)},
            Double.NEGATIVE_INFINITY);
        checkFunctionResult(
            new Value[] {
                makeBooleanValue(false), makeFloatValue(Double.NEGATIVE_INFINITY),
                makeFloatValue(Double.POSITIVE_INFINITY)},
            Double.POSITIVE_INFINITY);
        checkFunctionResult(
            new Value[] {
                makeBooleanValue(true), makeFloatValue(aValue), makeFloatValue(Double.NaN)},
            aValue);
        checkFunctionResult(
            new Value[] {
                makeBooleanValue(false), makeFloatValue(aValue), makeFloatValue(Double.NaN)},
            Double.NaN);
    }

}
