/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.selection;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestFloatFunction;


/**
 * Tests for {@link FnSelect} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnSelect extends BaseTestFloatFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnSelect() {
        super(new FnSelect());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        double aValue = 23.45e23;
        double bValue = -0.756;
        double cValue = 7.5;
        double dValue = -2.0;
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeIntegerValue(0)},
            aValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeIntegerValue(-2)},
            aValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeIntegerValue(3)},
            aValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(aValue), makeIntegerValue(-2), makeFloatValue(bValue),
                makeFloatValue(cValue)},
                aValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(aValue), makeIntegerValue(2), makeFloatValue(bValue),
                makeFloatValue(cValue)},
                aValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(aValue), makeIntegerValue(2), makeFloatValue(bValue),
                makeFloatValue(cValue), makeFloatValue(dValue)},
            dValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(aValue), makeIntegerValue(2), makeFloatValue(bValue),
                makeFloatValue(cValue), makeFloatValue(Double.NaN), makeFloatValue(dValue)},
            Double.NaN);
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        params[0] = makeFloatValue(aValue);
        params[1] = makeIntegerValue(DEFAULT_PARAMS_SOFT_LIMIT - 2 - 1);
        Arrays.fill(params, 2, params.length, makeFloatValue(bValue));
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = makeFloatValue(cValue);
        checkFunctionResult(params, cValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(Double.NaN), makeIntegerValue(5), makeFloatValue(bValue)},
                Double.NaN);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(aValue), makeIntegerValue(0), makeFloatValue(Double.NaN)},
                Double.NaN);
    }

}
