/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestIntegerFunction;


/**
 * Tests for {@link FnMultiplication} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnMultiplication extends BaseTestIntegerFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnMultiplication() {
        super(new FnMultiplication());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        long aValue = 123L;
        long bValue = -456L;
        checkFunctionResult(
            new Value[] {makeIntegerValue(aValue)},
            aValue);
        checkFunctionResult(
            new Value[] {makeIntegerValue(aValue), makeIntegerValue(1L)},
            aValue);
        checkFunctionResult(
            new Value[] {makeIntegerValue(aValue), makeIntegerValue(0L)},
            0L);
        checkFunctionResult(
            new Value[] {makeIntegerValue(aValue), makeIntegerValue(bValue)},
            aValue * bValue);
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, makeIntegerValue(1L));
        checkFunctionResult(params, 1L);
        params[0] = makeIntegerValue(aValue);
        checkFunctionResult(params, aValue);
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = makeIntegerValue(bValue);
        checkFunctionResult(params, aValue * bValue);
        checkFunctionResult(
            new Value[] {
                makeIntegerValue(aValue), makeIntegerValue(Long.MAX_VALUE),
                makeIntegerValue(bValue), makeIntegerValue(Long.MIN_VALUE)},
            aValue * Long.MAX_VALUE * bValue * Long.MIN_VALUE);
        checkFunctionResult(
            new Value[] {makeIntegerValue(Long.MAX_VALUE), makeIntegerValue(1L)},
            Long.MAX_VALUE);
    }

}
