/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.relations;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestBooleanFunction;


/**
 * Tests for {@link FnGreater} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnGreater extends BaseTestBooleanFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnGreater() {
        super(new FnGreater());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        long aValue = -234567890123L;
        long bValue = 17L;
        long cValue = 1002L;
        checkFunctionResultTrue(new Value[] {makeIntegerValue(aValue)});
        checkFunctionResultFalse(
            new Value[] {makeIntegerValue(aValue), makeIntegerValue(aValue)});
        checkFunctionResultFalse(
            new Value[] {makeIntegerValue(aValue), makeIntegerValue(bValue)});
        checkFunctionResultTrue(
            new Value[] {makeIntegerValue(bValue), makeIntegerValue(aValue)});
        checkFunctionResultTrue(
            new Value[] {
                makeIntegerValue(cValue), makeIntegerValue(bValue), makeIntegerValue(aValue)});
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, makeIntegerValue(aValue));
        checkFunctionResultFalse(params);
        params[0] = makeIntegerValue(bValue);
        checkFunctionResultFalse(params);
    }

}
