/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnAddition} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnAddition extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnAddition() {
        super(new FnAddition());
    }

    /**
     * Tests implementation of the function for non-empty parameters.
     */
    public void testEvaluateNotEmpty() {
        String aValue = "abc";
        String bValue = "d";
        Value[] aValueVariants = makeStringValueVariants(aValue);
        Value[] bValueVariants = makeStringValueVariants(bValue);
        for (int i = 0; i < aValueVariants.length; i++) {
            checkFunctionResultVarSizes(
                new Value[] {aValueVariants[i]},
                aValue);
        }
        for (int i = 0; i < aValueVariants.length; i++) {
            for (int j = 0; j < bValueVariants.length; j++) {
                checkFunctionResultVarSizes(
                    new Value[] {aValueVariants[i], bValueVariants[j]},
                    aValue + bValue);
                checkFunctionResultVarSizes(
                    new Value[] {aValueVariants[i], bValueVariants[j], aValueVariants[i]},
                    aValue + bValue + aValue);
            }
        }
    }

    /**
     * Tests implementation of the function for empty parameters.
     */
    public void testEvaluateEmpty() {
        String emptyValue = "";
        Value[] emptyVariants = makeStringValueVariants(emptyValue);
        for (int i = 0; i < emptyVariants.length; i++) {
            checkFunctionResultVarSizes(
                new Value[] {emptyVariants[i]},
                emptyValue);
            Value[] emptyParams = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
            Arrays.fill(emptyParams, emptyVariants[i]);
            checkFunctionResultVarSizes(
                emptyParams,
                emptyValue);
        }
    }

}
