/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnRepeat} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnRepeat extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnRepeat() {
        super(new FnRepeat());
    }

    /**
     * Evaluates {@link FnRepeat} function with given parameters using different variants of
     * <code>string</code> parameter {@link pl.chyla.wyjec.utils.RawString} equivalent and
     * checks if the result is always equal to the expected result.
     *
     * @param valueParam value of <code>value</code> parameter to pass to the function
     * @param repetitionsParam
     *     value of <code>repetitions</code> parameter to pass to the function 
     * @param expResult expected result of function evaluations
     */
    private void checkFnRepeat(String valueParam, long repetitionsParam, String expResult) {
        Value[] valueParamVariants = makeStringValueVariants(valueParam);
        for (int i = 0; i < valueParamVariants.length; i++) {
            checkFunctionResultVarSizes(
                new Value[] {valueParamVariants[i], makeIntegerValue(repetitionsParam)},
                expResult);
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnRepeat("", 0, "");
        checkFnRepeat("", 3, "");
        checkFnRepeat("x", 0, "");
        checkFnRepeat("x", 5, "xxxxx");
        checkFnRepeat("abc", 0, "");
        checkFnRepeat("abc", 4, "abcabcabcabc");
        checkFnRepeat("abc", -1, "");
        checkFnRepeat("abc", -5, "");
        checkFnRepeat("", Long.MIN_VALUE, "");
    }

}
