/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.relations;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestBooleanFunction;


/**
 * Tests for {@link FnLessOrEqual} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnLessOrEqual extends BaseTestBooleanFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnLessOrEqual() {
        super(new FnLessOrEqual());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        Value[] emptyVariants = makeStringValueVariants("");
        Value[] aValueVariants = makeStringValueVariants("ad4");
        Value[] bValueVariants = makeStringValueVariants("ad5");
        for (int ai = 0; ai < aValueVariants.length; ai++) {
            checkFunctionResultTrue(new Value[] {aValueVariants[ai]});
            for (int aj = 0; aj < aValueVariants.length; aj++) {
                checkFunctionResultTrue(new Value[] {aValueVariants[ai], aValueVariants[aj]});
            }
            for (int bi = 0; bi < bValueVariants.length; bi++) {
                Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
                Arrays.fill(params, aValueVariants[ai]);
                checkFunctionResultTrue(params);
                params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = bValueVariants[bi];
                checkFunctionResultTrue(params);
                Arrays.fill(params, aValueVariants[ai]);
                params[0] = bValueVariants[bi];
                checkFunctionResultFalse(params);
            }
        }
        for (int ei = 0; ei < emptyVariants.length; ei++) {
            for (int ai = 0; ai < aValueVariants.length; ai++) {
                for (int bi = 0; bi < bValueVariants.length; bi++) {
                    checkFunctionResultTrue(
                        new Value[] {
                            emptyVariants[ei], aValueVariants[ai], bValueVariants[bi]});
                    checkFunctionResultTrue(
                        new Value[] {
                            emptyVariants[ei], emptyVariants[ei], aValueVariants[ai],
                            aValueVariants[ai], bValueVariants[bi], bValueVariants[bi]});
                }
                checkFunctionResultFalse(
                    new Value[] {emptyVariants[ei], aValueVariants[ai], emptyVariants[ei]});
            }
        }
    }

}
