/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.selection;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnMin} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnMin extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnMin() {
        super(new FnMin());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        String aValue = "q";
        String bValue = "XY";
        String cValue = "abcdefghij";
        checkFunctionResultVarSizes(
            new Value[] {makeStringValue(aValue)},
            aValue);
        Value[] aValueVariants = makeStringValueVariants(bValue);
        Value[] bValueVariants = makeStringValueVariants(cValue);
        for (int ai = 0; ai < aValueVariants.length; ai++) {
            for (int bi = 0; bi < bValueVariants.length; bi++) {
                checkFunctionResultVarSizes(
                    new Value[] {
                        aValueVariants[ai], bValueVariants[bi], bValueVariants[bi]},
                    bValue);
                checkFunctionResultVarSizes(
                    new Value[] {
                        bValueVariants[ai], aValueVariants[ai], aValueVariants[ai]},
                    bValue);
                Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
                Arrays.fill(params, bValueVariants[bi]);
                checkFunctionResultVarSizes(params, cValue);
                params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = aValueVariants[ai];
                checkFunctionResultVarSizes(params, bValue);
                Arrays.fill(params, bValueVariants[bi]);
                params[0] = aValueVariants[ai];
                checkFunctionResultVarSizes(params, bValue);
            }
        }
    }

}
