/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.utils;


/**
 * Factory for plain <code>Object</code> instances, counting all created instances.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public class CountingObjectsFactory implements IObjectsFactory {

    /**
     * A number of created instances.
     */
    private int instancesCount;

    /**
     * Generates new <code>Object</code> instance and increases internal instances counter.
     */
    public Object createObject() {
        instancesCount++;
        return new Object();
    }

    /**
     * Returns a number of <code>Object</code> instances generated until now.
     *
     * @return number of generated instances
     */
    int getInstancesCount() {
        return instancesCount;
    }

}
