/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.utils;

import java.util.Arrays;
import junit.framework.TestCase;


/**
 * Tests for {@link ArrayUtils} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestArrayUtils extends TestCase {

    /**
     * Sample string for use in tests
     */
    private static final String SAMPLE_STRING = "sample string";

    /**
     * Empty default constructor
     */
    public TestArrayUtils() { }

    /**
     * Tests {@link ArrayUtils#copyArray(Object[], Object[]) method.
     */
    public void testCopyArray() {
        Object[][] sources = {
            new String[] {},
            new String[] {new String(), new String()},
            new Object[] {},
            new Object[] {new Object(), new Object(), new Object()}};
        for (int si = 0; si < sources.length; si++) {
            Object[] src = sources[si];
            for (int destLen = src.length; destLen < src.length * 2; destLen++) {
                Object[] dest = new Object[destLen];
                ArrayUtils.copyArray(src, dest);
                for (int i = 0; i < src.length; i++) {
                    assertEquals(src[i], dest[i]);
                }
                for (int i = src.length; i < destLen; i++) {
                    assertEquals(dest[i], null);
                }
            }
        }

    }

    /**
     * Tests {@link ArrayUtils#getCharSubArray(char[], int, int) method.
     */
    public void testGetCharSubArray() {
        // sub-arrays of sample array
        char[] chars = SAMPLE_STRING.toCharArray();
        for (int startPos = 0; startPos <= chars.length; startPos++) {
            for (int len = 0; len <= chars.length - startPos; len++) {
                char[] sub = ArrayUtils.getCharSubArray(chars, startPos, len);
                assertEquals(new String(sub), new String(chars, startPos, len));
            }
        }
        // empty sub-array of empty array
        assertEquals(new String(ArrayUtils.getCharSubArray(new char[0], 0, 0)), "");
    }

    /**
     * Tests {@link ArrayUtils#flattenArrays(Object[][], Object[])}
     */
    public void testFlattenArrays() {
        String[][] aArrays = {};
        String[] aArray = (String[]) ArrayUtils.flattenArrays(aArrays, new String[0]);
        assertEquals(aArray.length, 0);
        String[][] bArrays = {
            {}, {}, {}};
        String[] bArray = (String[]) ArrayUtils.flattenArrays(bArrays, new String[0]);
        assertEquals(bArray.length, 0);
        String[][] cArrays = {
            {}, {"a", "b", "c"}, {}, {"d"}};
        String[] cArray = (String[]) ArrayUtils.flattenArrays(cArrays, new String[0]);
        assertTrue(Arrays.equals(cArray, new String[] {"a", "b", "c", "d"}));
    }

}
