/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.utils;

import java.util.Calendar;
import java.util.Locale;
import java.util.TimeZone;
import junit.framework.TestCase;


/**
 * Tests for {@link SimpleCalendar} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestSimpleCalendar extends TestCase {

    /**
     * <code>SimpleCalendar</code> instance used for testing.
     */
    SimpleCalendar cal;

    /**
     * Empty default constructor
     */
    public TestSimpleCalendar() { }

    /**
     * {@inheritDoc}
     */
    protected void setUp() throws Exception {
        super.setUp();
        cal = new SimpleCalendar();
    }

    /**
     * Tests whether the calendar uses GMT time zone.
     */
    public void testGMTTimeZone() {
        assertEquals(cal.getTimeZone().getID(), "GMT");
        assertEquals(cal.getTimeZone().getRawOffset(), 0);
        cal.setDate(1970, 0, 1, 0, 0, 0);
        cal.set(Calendar.MILLISECOND, 0);
        assertEquals(cal.getTimeInMillis(), 0);
    }

    /**
     * Tests whether the calendar uses English locale.
     */
    public void testEnglishLocale() {
        assertEquals(cal.getFirstDayOfWeek(), Calendar.SUNDAY);
    }

    /**
     * Tests whether {@link SimpleCalendar#SimpleCalendar(TimeZone, Locale)} constructor uses
     * specified time zone.
     */
    public void testOtherTimeZone() {
        cal = new SimpleCalendar(TimeZone.getTimeZone("CET"), Locale.UK);
        assertEquals(cal.getTimeZone().getID(), "CET");
    }

    /**
     * Tests whether {@link SimpleCalendar#SimpleCalendar(TimeZone, Locale)} constructor uses
     * specified locale.
     */
    public void testOtherLocale() {
        cal = new SimpleCalendar(TimeZone.getTimeZone("GMT"), Locale.GERMANY);
        assertEquals(cal.getFirstDayOfWeek(), Calendar.MONDAY);
    }

    /**
     * Tests {@link SimpleCalendar#setDate(int, int, int)} method.
     */
    public void testSetDateYMD() {
        cal.setDate(1977, 2, 9);
        assertEquals(cal.get(Calendar.YEAR), 1977);
        assertEquals(cal.get(Calendar.MONTH), 2);
        assertEquals(cal.get(Calendar.DAY_OF_MONTH), 9);
        assertEquals(cal.get(Calendar.HOUR_OF_DAY), 0);
        assertEquals(cal.get(Calendar.HOUR), 0);
        assertEquals(cal.get(Calendar.MINUTE), 0);
        assertEquals(cal.get(Calendar.SECOND), 0);
        assertEquals(cal.get(Calendar.MILLISECOND), 0);
    }

    /**
     * Tests {@link SimpleCalendar#setDate(int, int, int, int, int, int)} method.
     */
    public void testSetDateYMDHMS() {
        cal.setDate(1977, 2, 9, 21, 20, 19);
        assertEquals(cal.get(Calendar.YEAR), 1977);
        assertEquals(cal.get(Calendar.MONTH), 2);
        assertEquals(cal.get(Calendar.DAY_OF_MONTH), 9);
        assertEquals(cal.get(Calendar.HOUR_OF_DAY), 21);
        assertEquals(cal.get(Calendar.HOUR), 9);
        assertEquals(cal.get(Calendar.MINUTE), 20);
        assertEquals(cal.get(Calendar.SECOND), 19);
        assertEquals(cal.get(Calendar.MILLISECOND), 0);
    }

}
